%define orthancclientversion 0.7
%define orthancversion 0.7.2

Name:		orthanc_epel
Version:	%{orthancversion}
Release:	2%{?dist}
Summary:	RESTful DICOM server for healthcare and medical research
License:	GPLv3 with exceptions
URL:		https://code.google.com/p/orthanc/
Source0:	https://orthanc.googlecode.com/files/Orthanc-%{version}.tar.gz
Source1:	orthanc.json
Source2:	orthanc.service
Source3:	orthancclient.README
Source4:	orthanc.init

# This patch fixes the installation path of the 64bit version of the
# client library
Patch1:	     	orthanc-%{orthancversion}-lib64.patch

%if 0%{?fedora}
BuildRequires:	boost-devel
BuildRequires:	cmake 
BuildRequires:	curl-devel
BuildRequires:	dcmtk-devel
BuildRequires:	glog-devel
BuildRequires:	gtest-devel
BuildRequires:	jsoncpp-devel
BuildRequires:	libsqlite3x-devel
BuildRequires:	mongoose-devel
BuildRequires:	systemd
%endif
%if 0%{?el6}
BuildRequires:	cmake28 
BuildRequires:	libcurl-devel
BuildRequires:	sqlite-devel
%endif

BuildRequires:	doxygen
BuildRequires:	help2man
BuildRequires:	lua-devel >= 5.1.0
BuildRequires:	libpng-devel
BuildRequires:	libuuid-devel
BuildRequires:	openssl-devel
BuildRequires:	python


# The following line is required to add the "orthanc" user and group
Requires(pre):	shadow-utils

%if 0%{?fedora}
# The following lines are required to install the Systemd service
# https://fedoraproject.org/wiki/Packaging:ScriptletSnippets?rd=Packaging/ScriptletSnippets#Macroized_scriptlets_.28Fedora_18.2B.29
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
%endif
%if 0%{?el6}
Requires(post): chkconfig
Requires(preun): chkconfig
Requires(preun): initscripts
Requires(postun): initscripts
%endif

%description
Orthanc aims at providing a simple, yet powerful standalone DICOM
server. Orthanc can turn any computer running Windows or Linux into a
DICOM store (in other words, a mini-PACS system). Its architecture is
lightweight, meaning that no complex database administration is
required, nor the installation of third-party dependencies.

What makes Orthanc unique is the fact that it provides a RESTful
API. Thanks to this major feature, it is possible to drive Orthanc
from any computer language. The DICOM tags of the stored medical
images can be downloaded in the JSON file format. Furthermore,
standard PNG images can be generated on-the-fly from the DICOM
instances by Orthanc.

Orthanc lets its users focus on the content of the DICOM files,
hiding the complexity of the DICOM format and of the DICOM protocol.


%package -n orthancclient-lib
Summary:        Orthanc Client library
Group:          System/Libraries

%description -n orthancclient-lib
Orthanc Client is a library to access the content of a remote instance
of Orthanc. Orthanc is a lightweight, RESTful DICOM server for
healthcare and medical research.

%package -n orthancclient-devel
Summary:        Header files for Orthanc Client library
Group:          Development/Libraries/C and C++
Requires:	orthancclient-lib = %{version}-%{release}
%if 0%{?fedora}
Requires:	cmake >= 2.8.0
Requires:	boost
Requires:	curl
Requires:	libpng
Requires:	openssl
Requires:	jsoncpp
%endif

%description -n orthancclient-devel
This package contains the development and header files for the Orthanc
Client library.


%package -n orthancclient-doc
Summary:        Documentation files for Orthanc Client library
Group:          Documentation
BuildArch:	noarch

%description -n orthancclient-doc
This package contains the API document of the Orthanc Client library,
and sample codes.



%prep
%setup -q -n Orthanc-%{version}
%patch1

# Copy the configuration file and the Systemd Service for the Orthanc server
cp -p %SOURCE1 orthanc.json
cp -p %SOURCE2 orthanc.service
cp -p %SOURCE3 orthancclient.README
cp -p %SOURCE4 orthanc.init


%build
%if 0%{?fedora}
%cmake	-DSTATIC_BUILD:BOOL=OFF \
	-DSTANDALONE_BUILD:BOOL=ON \
	-DCMAKE_BUILD_TYPE=Release \
	.
%endif
%if 0%{?el6}
%cmake28 -DSTATIC_BUILD:BOOL=OFF \
	-DSTANDALONE_BUILD:BOOL=ON \
	-DCMAKE_BUILD_TYPE=Release \
	-DALLOW_DOWNLOADS=ON \
	-DUSE_SYSTEM_BOOST=OFF \
	-DUSE_SYSTEM_CURL=ON \
	-DUSE_SYSTEM_DCMTK=OFF \
	-DUSE_SYSTEM_GOOGLE_LOG=OFF \
	-DUSE_SYSTEM_GOOGLE_TEST=OFF \
	-DUSE_SYSTEM_JSONCPP=OFF \
	-DUSE_SYSTEM_LIBPNG=ON \
	-DUSE_SYSTEM_LIBLUA=ON \
	-DUSE_SYSTEM_MONGOOSE=OFF \
	-DUSE_SYSTEM_SQLITE=OFF \
	.
%endif

make %{?_smp_mflags}

# Generate the man page
help2man ./Orthanc -N -n "Lightweight, RESTful DICOM server for healthcare and medical research" > Orthanc.1


%check
# Execute the unit tests
./UnitTests


%install
make install DESTDIR=%{buildroot}

install -m 755 -d %{buildroot}%{_mandir}/man1
cp Orthanc.1 %{buildroot}%{_mandir}/man1

install -m 755 -d %{buildroot}%{_sysconfdir}/orthanc
cp orthanc.json %{buildroot}%{_sysconfdir}/orthanc

%if 0%{?fedora}
install -m 755 -d %{buildroot}%{_unitdir}
cp orthanc.service %{buildroot}%{_unitdir}
%endif
%if 0%{?el6}
install -m 755 -d %{buildroot}%{_sysconfdir}/init.d/
cp orthanc.init %{buildroot}%{_sysconfdir}/init.d/orthanc
%endif

install -m 755 -d %{buildroot}%{_sharedstatedir}/orthanc/db-v3

# Copy the Doxgen documentation of Orthanc Client
mv %{buildroot}%{_docdir}/orthanc %{buildroot}%{_docdir}/orthancclient-%{orthancversion}

# README file for the Orthanc Client
cp orthancclient.README %{buildroot}%{_docdir}/orthancclient-%{orthancversion}/README

# Copy sample codes for the Orthanc Client
cp -r Resources/Samples/OrthancClient %{buildroot}%{_docdir}/orthancclient-%{orthancversion}/Samples


%files
%doc NEWS README THANKS COPYING
%{_mandir}/man1/*.1*
%{_sbindir}/*
%if 0%{?fedora}
%{_unitdir}/orthanc.service
%endif
%if 0%{?el6}
%{_sysconfdir}/init.d/orthanc
%endif

%dir %{_sysconfdir}/orthanc
%config(noreplace) %{_sysconfdir}/orthanc/orthanc.json
%dir %attr(0755, orthanc, orthanc) %{_sharedstatedir}/orthanc
%dir %attr(0755, orthanc, orthanc) %{_sharedstatedir}/orthanc/db-v3


%files -n orthancclient-lib
%defattr(-,root,root,-)
%{_libdir}/*.so.*


%files -n orthancclient-devel
%defattr(-,root,root,-)
%{_includedir}/*
%{_libdir}/*.so


%files -n orthancclient-doc
%defattr(-,root,root,-)
%{_docdir}/orthancclient-%{orthancversion}/*


# Installation of the Systemd Orthanc service
# https://fedoraproject.org/wiki/Packaging:ScriptletSnippets#Systemd
%post
%if 0%{?fedora}
%systemd_post orthanc.service
%endif
%if 0%{?el6}
/sbin/chkconfig --add orthanc 
%endif

%preun
%if 0%{?fedora}
%systemd_preun orthanc.service
%endif
%if 0%{?el6}
if [ $1 -eq 0 ] ; then
    /sbin/service orthanc stop >/dev/null 2>&1
    /sbin/chkconfig --del orthanc
fi
%endif

%postun
%if 0%{?fedora}
%systemd_postun_with_restart orthanc.service
%endif
%if 0%{?el6}
if [ "$1" -ge "1" ] ; then
    /sbin/service <script> condrestart >/dev/null 2>&1 || :
fi
%endif

%pre
# http://fedoraproject.org/wiki/Packaging%3aUsersAndGroups
# "We never remove users or groups created by packages"

getent group orthanc >/dev/null || groupadd -r orthanc
getent passwd orthanc >/dev/null || \
    useradd -r -g orthanc -G orthanc -d %{_sharedstatedir}/orthanc -s /sbin/nologin \
    -c "User account that holds information for Orthanc" orthanc
exit 0


%changelog
* Thu Nov 14 2013 Mario Ceresa <mrceresa@fedoraproject.org> 0.7.2-2
- Fixed error in creation of init.d dir

* Thu Nov 14 2013 Mario Ceresa <mrceresa@fedoraproject.org> 0.7.2-1
- New version
- Added upstart script adapted from: 
- https://groups.google.com/forum/#!topic/orthanc-users/d1v1k2KYx4A)

* Wed Nov 13 2013 Mario Ceresa <mrceresa@fedoraproject.org> 0.7.1-9
- Use systemd for Fedora only

* Wed Nov 13 2013 Mario Ceresa <mrceresa@fedoraproject.org> 0.7.1-8
- Boost errors in el6. Build from scratch.

* Wed Nov 13 2013 Mario Ceresa <mrceresa@fedoraproject.org> 0.7.1-7
- sqlite in centos is too old. Build from scratch

* Wed Nov 13 2013 Mario Ceresa <mrceresa@fedoraproject.org> 0.7.1-6
- Use cmake28 on rhel

* Wed Nov 13 2013 Mario Ceresa <mrceresa@fedoraproject.org> 0.7.1-5
- rh 6 does not ship systemd. 

* Wed Nov 13 2013 Mario Ceresa <mrceresa@fedoraproject.org> 0.7.1-4
- Added conditional compilation for epel and fedora

* Wed Nov 13 2013 Mario Ceresa <mrceresa@fedoraproject.org> 0.7.1-3
- Removed BRs for packages that build from source

* Wed Nov 13 2013 Mario Ceresa <mrceresa@fedoraproject.org> 0.7.1-2
- Test changes to build in EPEL
- Let's enable download and build boost, dcmtk, mongoose, jsoncpp components

* Wed Oct 30 2013 Sebastien Jodogne <s.jodogne@gmail.com> 0.7.1-1
- New upstream version
- Fix for big endian architectures (bug #985748)
- Packaging of the Orthanc Client library

* Mon Sep 16 2013 Sebastien Jodogne <s.jodogne@gmail.com> 0.6.1-1
- New upstream version

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sat Jul 27 2013 pmachata@redhat.com - 0.6.0-2
- Rebuild for boost 1.54.0

* Tue Jul 16 2013 Sebastien Jodogne <s.jodogne@gmail.com> 0.6.0-1
- New upstream version

* Wed May  8 2013 Sebastien Jodogne <s.jodogne@gmail.com> 0.5.2-1
- New upstream version

* Wed Apr 17 2013 Sebastien Jodogne <s.jodogne@gmail.com> 0.5.1-1
- New upstream version

* Thu Apr 04 2013 Sebastien Jodogne <s.jodogne@gmail.com> 0.5.0-1
- New upstream version

* Wed Dec 19 2012 Sebastien Jodogne <s.jodogne@gmail.com> 0.4.0-5
- Fixes according to reviews

* Wed Dec 19 2012 Sebastien Jodogne <s.jodogne@gmail.com> 0.4.0-4
- Dynamic linking against mongoose-lib

* Wed Dec 19 2012 Sebastien Jodogne <s.jodogne@gmail.com> 0.4.0-3
- Improvements to the packaging

* Tue Dec 18 2012 Sebastien Jodogne <s.jodogne@gmail.com> 0.4.0-2
- Improvements to the packaging

* Mon Dec 17 2012 Sebastien Jodogne <s.jodogne@gmail.com> 0.4.0-1
- Initial RPM Release
